==> 0.1.0.tar.gz: lib/flight_script.dart <==
library flight_script;

import 'package:flight_script/vm/dictionary.dart';
import 'package:flight_script/vm/function.dart';
import 'package:flight_script/vm/host_function.dart';
import 'package:flight_script/vm/macro.dart';
import 'package:flight_script/vm/stack.dart';
import 'package:flight_script/vm/stdlib.dart';
import 'package:flight_script/vm/virtual_machine.dart';

import 'rpn/parser.dart';

export 'libs/dart_api.dart' show DartCompoundApi, DartSimpleApi;
export 'libs/lib.dart' show Library, LoadLibrary;
export 'vm/virtual_machine.dart' show VirtualMachine;

/// A vm for debugging efforts. Prints each evaluated value and the stack after
/// it's evaluated
/// We expect there to only be one stack listener, so we can extract the value
/// with a slightly hacky call
class DebugVm extends VirtualMachine {
  late final StackListener _stack;

  @override
  void pushListener(ValueListener listener) {
    if (listener is StackListener) {
      _stack = listener;
    }
    super.pushListener(listener);
  }

  @override
  dynamic eval(value) {
    final retval = super.eval(value);
    print(
        "${_valueString(value)}\t\t(${List.of(_stack.stack).map((it) => _valueString(it)).join(" ")})");
    return retval;
  }

  String _valueString(value) {
    if (value is DartFunction) {
      return "fn(~native)";
    }
    return value.toString();
  }
}

class Interpreter {
  final VirtualMachine vm;

  Interpreter({VirtualMachine? vm}) : this.vm = vm ?? VirtualMachine() {
    this.vm.pushListener(StackListener());
    this.vm.pushListener(DictionaryListener());
    this.vm.pushListener(HostFunctionListener());
    this.vm.pushListener(MacroListener());
    this.vm.pushListener(FlightFunctionListener());
    this.vm.loadStdLib();
  }

  List<dynamic> eval(String input) {
    final program = Parser().parse(input).toList();
    vm.eval(Macro(program));
    return vm.eval(Stack());
  }

  void bind(String name, DartFunction fn) => vm[name] = fn;
}

==> 0.1.2.tar.gz: lib/flight_script.dart <==
library flight_script;

import 'src/dictionary.dart';
import 'src/function.dart';
import 'src/host_function.dart';
import 'src/macro.dart';
import 'src/stack.dart';
import 'src/stdlib.dart';
import 'src/virtual_machine.dart';
import 'src/parser/parser.dart';

export 'src/virtual_machine.dart' show VirtualMachine;
export 'src/dictionary.dart' show DictionaryApi;
export 'src/stack.dart' show StackApi;
export 'src/stdlib.dart' show StdLib;
export 'src/deferred.dart' show DeferredExecutionApi;
export 'src/macro.dart' show MacroBuilderApi;

/// A vm for debugging efforts. Prints each evaluated value and the stack after
/// it's evaluated
/// We expect there to only be one stack listener, so we can extract the value
/// with a slightly hacky call
class DebugVm extends VirtualMachine {
  late final StackListener _stack;

  @override
  void pushListener(ValueListener listener) {
    if (listener is StackListener) {
      _stack = listener;
    }
    super.pushListener(listener);
  }

  @override
  dynamic eval(value) {
    final retval = super.eval(value);
    print(
        "${_valueString(value)}\t\t(${List.of(_stack.stack).map((it) => _valueString(it)).join(" ")})");
    return retval;
  }

  String _valueString(value) {
    if (value is DartFunction) {
      return "fn(~native)";
    }
    return value.toString();
  }
}

class Interpreter {
  final VirtualMachine vm;

  Interpreter({VirtualMachine? vm}) : this.vm = vm ?? VirtualMachine() {
    this.vm.pushListener(StackListener());
    this.vm.pushListener(DictionaryListener());
    this.vm.pushListener(HostFunctionListener());
    this.vm.pushListener(MacroListener());
    this.vm.pushListener(FlightFunctionListener());
    this.vm.loadStdLib();
  }

  List<dynamic> eval(String input) {
    final program = Parser().parse(input).toList();
    vm.eval(Macro(program));
    return vm.eval(Stack());
  }

  void bind(String name, DartFunction fn) => vm[name] = fn;
}
